@@ -2,7 +2,7 @@ import argparse
 import shutil
 from pathlib import Path
 
-from smart_workspace import WorkSpacer
+from . import WorkSpacer
 
 template_position = Path(__file__).parent.joinpath('templates')
 
